scandit_flutter_datacapture_id library
Classes
- AamvaBarcodeVerificationResult
- BarcodeResult
- CapturedId
- DataConsistencyResult
- The verification result of a comparison between the human-readable data of the document with the data encoded in either MRZ or barcode. This result can be returned by DataConsistencyVerifier or performed automatically when IdCaptureSettings.RejectInconsistentData is enabled and exposed on VerificationResult.
- DateResult
- DriverLicense
- DrivingLicenseCategory
- DrivingLicenseDetails
- FullDocumentScanner
- HealthInsuranceCard
- IdCapture
- IdCaptureDocument
- IdCaptureFeedback
- IdCaptureListener
- IdCaptureOverlay
- IdCaptureScanner
- IdCaptureSettings
- IdCard
- IdImages
- MobileDocumentOcrResult
- MobileDocumentResult
- MobileDocumentScanner
- MrzResult
- Passport
- PhysicalDocumentScanner
- ProfessionalDrivingPermit
- RegionSpecific
- ResidencePermit
- ScanditFlutterDataCaptureId
- SingleSideScanner
- VehicleRestriction
- VerificationResult
- VisaDetails
- VisaIcao
- VisaLetter
- VizResult
Enums
- AamvaBarcodeVerificationStatus
- The verification status returned by the barcode verifier.
- ApplicationStatus
- CapturedSides
- DataConsistencyCheck
- IdAnonymizationMode
- IdCaptureDocumentType
- IdCaptureRegion
- IdFieldType
- IdImageType
- IdLayoutLineStyle
- IdLayoutStyle
- IdSide
- MobileDocumentDataElement
- RegionSpecificSubtype
- RejectionReason
- Sex
- TextHintPosition
- UsRealIdStatus