IdCaptureDocument class abstract

Implementers

Properties

documentType IdCaptureDocumentType
no setter
hashCode int
The hash code for this object.
no setterinherited
isDriverLicense bool
no setter
isHealthInsuranceCard bool
no setter
isIdCard bool
no setter
isPassport bool
no setter
isRegionSpecific bool
no setter
isResidencePermit bool
no setter
isVisaIcao bool
no setter
isVisaLetter bool
no setter
region IdCaptureRegion
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited